@@ -4,9 +4,10 @@ from typing import Optional, Dict, List
 from packaging.version import Version
 
 from agentbox.sandbox.sandbox_api import SandboxInfo, SandboxApiBase, SandboxQuery, ListedSandbox
-from agentbox.exceptions import TemplateException
+from agentbox.exceptions import TemplateException, SandboxException
 from agentbox.api import ApiClient, SandboxCreateResponse
-from agentbox.api.client.models import NewSandbox, PostSandboxesSandboxIDTimeoutBody, SandboxADB, SandboxSSH, InstanceAuthInfo
+from agentbox.api.client.models import NewSandbox, PostSandboxesSandboxIDTimeoutBody, SandboxADB, SandboxADBPublicInfo, SandboxSSH, InstanceAuthInfo, ResumedSandbox, Sandbox, Error, ConnectSandbox
+
 from agentbox.api.client.api.sandboxes import (
     get_sandboxes_sandbox_id,
     post_sandboxes_sandbox_id_timeout,
@@ -14,12 +15,17 @@ from agentbox.api.client.api.sandboxes import (
     delete_sandboxes_sandbox_id,
     post_sandboxes,
     get_sandboxes_sandbox_id_adb,
+    get_sandboxes_sandbox_id_adb_public_info,
     get_sandboxes_sandbox_id_ssh,
     get_sandboxes_sandbox_id_instance_no,
     get_sandboxes_sandbox_id_instance_auth_info,
+    post_sandboxes_sandbox_id_pause,
+    post_sandboxes_sandbox_id_resume,
+    post_sandboxes_sandbox_id_connect,
 )
 from agentbox.connection_config import ConnectionConfig, ProxyTypes
 from agentbox.api import handle_api_exception
+from httpx import HTTPTransport
 
 
 class SandboxApi(SandboxApiBase):
@@ -37,7 +43,7 @@ class SandboxApi(SandboxApiBase):
         """
         List all running sandboxes.
 
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
         :param query: Filter the list of sandboxes, e.g. by metadata `SandboxQuery(metadata={"key": "value"})`, if there are multiple filters they are combined with AND.
         :param domain: Domain to use for the request, only relevant for self-hosted environments
         :param debug: Enable debug mode, all requested are then sent to localhost
@@ -112,9 +118,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox info.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
 
@@ -174,9 +180,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox instance number.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
 
@@ -218,13 +224,14 @@ class SandboxApi(SandboxApiBase):
         request_timeout: Optional[float] = None,
         headers: Optional[Dict[str, str]] = None,
         proxy: Optional[ProxyTypes] = None,
+        valid_time: Optional[int] = 3600,
     ) -> InstanceAuthInfo:
         """
         Get the sandbox instance auth info(userId, instanceNo, accessKey, accessSecretKey, expireTime).
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
 
@@ -245,6 +252,7 @@ class SandboxApi(SandboxApiBase):
         ) as api_client:
             res = get_sandboxes_sandbox_id_instance_auth_info.sync_detailed(
                 sandbox_id,
+                valid_time=valid_time,
                 client=api_client,
             )
 
@@ -255,7 +263,83 @@ class SandboxApi(SandboxApiBase):
                 raise Exception("Body of the request is None")
 
             return res.parsed
-        
+
+    @classmethod
+    def _cls_resume(
+        cls,
+        sandbox_id: str,
+        timeout: int,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+    ) -> bool:
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+        )
+
+        with ApiClient(
+            config,
+            limits=SandboxApiBase._limits,
+        ) as api_client:
+            res = post_sandboxes_sandbox_id_resume.sync_detailed(
+                sandbox_id,
+                client=api_client,
+                body=ResumedSandbox(
+                    timeout=timeout,
+                ),
+            )
+
+            if res.status_code == 404:
+                raise Exception(f"Paused sandbox {sandbox_id} not found")
+
+            if res.status_code == 409:
+                return False
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            return True
+
+    @classmethod
+    def _cls_pause(
+        cls,
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+    ) -> bool:
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+        )
+
+        with ApiClient(
+            config,
+            limits=SandboxApiBase._limits,
+        ) as api_client:
+            res = post_sandboxes_sandbox_id_pause.sync_detailed(
+                sandbox_id,
+                client=api_client,
+            )
+
+            if res.status_code == 404:
+                raise Exception(f"Sandbox {sandbox_id} not found")
+
+            if res.status_code == 409:
+                return False
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            return True
+
     @classmethod
     def _get_adb(
         cls,
@@ -270,9 +354,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox ADB information.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
         :param proxy: Proxy to use for the request
@@ -304,6 +388,55 @@ class SandboxApi(SandboxApiBase):
                 raise Exception("Body of the request is None")
 
             return res.parsed
+        
+    @classmethod
+    def _get_adb_public_info(
+        cls,
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+        headers: Optional[Dict[str, str]] = None,
+        proxy: Optional[ProxyTypes] = None,
+    ) -> SandboxADBPublicInfo:
+        """
+        Get the sandbox ADB public information.
+        :param sandbox_id: Sandbox ID
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
+        :param request_timeout: Timeout for the request in **seconds**
+        :param headers: Additional headers to send with the request
+        :param proxy: Proxy to use for the request
+
+        :return: Sandbox ADB info
+        """
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+            headers=headers,
+            proxy=proxy,
+        )
+
+        with ApiClient(
+            config,
+            limits=cls._limits,
+        ) as api_client:
+            res = get_sandboxes_sandbox_id_adb_public_info.sync_detailed(
+                sandbox_id,
+                client=api_client,
+            )
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            if res.parsed is None:
+                raise Exception("Body of the request is None")
+
+            return res.parsed
 
     @classmethod
     def _get_ssh(
@@ -319,9 +452,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox SSH information.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
         :param proxy: Proxy to use for the request
@@ -448,6 +581,7 @@ class SandboxApi(SandboxApiBase):
         request_timeout: Optional[float] = None,
         headers: Optional[Dict[str, str]] = None,
         proxy: Optional[ProxyTypes] = None,
+        auto_pause: bool = False,
     ) -> SandboxCreateResponse:
         config = ConnectionConfig(
             api_key=api_key,
@@ -466,6 +600,7 @@ class SandboxApi(SandboxApiBase):
                     timeout=timeout,
                     env_vars=env_vars or {},
                     secure=secure or False,
+                    auto_pause=auto_pause,
                 ),
                 client=api_client,
             )
@@ -496,3 +631,48 @@ class SandboxApi(SandboxApiBase):
                 envd_version=res.parsed.envd_version,
                 envd_access_token=res.parsed.envd_access_token,
             )
+
+    @classmethod
+    def _cls_connect(
+        cls,
+        sandbox_id: str,
+        timeout: Optional[int] = None,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+        headers: Optional[Dict[str, str]] = None,
+        proxy: Optional[ProxyTypes] = None,
+    ) -> Sandbox:
+        
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+            headers=headers,
+            proxy=proxy,
+        )
+
+        with ApiClient(
+            config,
+            limits=SandboxApiBase._limits,
+        ) as api_client:
+            res = post_sandboxes_sandbox_id_connect.sync_detailed(
+                sandbox_id,
+                client=api_client,
+                body=ConnectSandbox(
+                    timeout=timeout,
+                ),
+            )
+
+            if res.status_code == 404:
+                raise Exception(f"Sandbox {sandbox_id} not found")
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            if isinstance(res.parsed, Error):
+                raise SandboxException(f"{res.parsed.message}: Request failed")
+
+            return res.parsed
\ No newline at end of file
